jQuery MultiSelect Widget Demo

## Show/hide with Animation

Using animations with the show and hide parameters. Either pass an array with the effect name and the speed, or just specify the name of an effect. If you don't specify a speed, the default of 400ms will be used.

### Specifying different show and hide speeds

    $("#test-1").multiselect({
       show: ["bounce", 200],
       hide: ["explode", 1000]
    });

### Only passing the name of an effect

    $("#test-2").multiselect({
       show: "bounce",
       hide: "explode"
    });